@@ -14,11 +14,10 @@ import sys
 import zipfile
 from datetime import datetime
 from subprocess import Popen, PIPE, TimeoutExpired
-from xml.dom import minidom
-from xml.dom.minidom import Element
 
 import plogger
 import winrm
+import xmltodict
 from requests.exceptions import ConnectionError
 from winrm import Protocol
 from winrm.exceptions import (InvalidCredentialsError,
@@ -614,63 +613,44 @@ class WinOSClient:
                 hash_.update(data)
             return hash_.hexdigest()
 
-    def get_xml(self):
-        # (Select-Xml -Path D:\Test.xml -XPath "/configuration/parameters/logging/LogLevel").Node.Value
+    def get_xml(self, file_name: str, xml_attribs: bool = False) -> dict:
+        """Parse specified xml file's content
 
-        deprecate_msg = '.get_xml* methods deprecated and will be removed. Use xmltodict package and UNC path instead!'
-        self.logger.warning(deprecate_msg)
-
-        msg = 'Use .run_ps() and "Select-Xml" cmdlet. Select-Xml -Path D:\\Test.xml -XPath "/configuration"'
-        raise NotImplementedError(msg)
-
-    def get_xml_dom_local(self, path: str, tag: str = None) -> Element:
-        """Parse local XML file using dom.
-
-        Methods to get info from dom: getElementsByTagName(), getElementById()
-
-        >>> root_root = WinOSClient.get_xml_dom_local(path)
-        >>> root_root.getElementsByTagName('LogLevel')
-        >>> root_root.getElementsByTagName('LogLevel')[0].attributes['value'].value
-        >>> WinOSClient.get_xml_dom_local(path, tag='LogLevel')
-
-        :param path: File path
-        :param tag: Get tag element. "GuiMonitoringAllowed"
-        :return: root or tag element
+        :param file_name: XML file path
+        :return:
         """
 
-        deprecation_message = '.get_xml*_local methods deprecated and will be removed. Use xmltodict package instead!'
-        self.logger.warning(deprecation_message)
-
-        root = minidom.parse(path)
-        if tag:
-            return root.getElementsByTagName(tag)
-        return root
-
-    def get_xml_tree_local(self, path: str, tag: str = None):
-        """Parse local XML file using tree.
-
-        :param path: file path
-        :param tag: Get tag text. "flags/GuiMonitoringAllowed"
-        :return: root or tag text
-        """
-
-        deprecation_message = '.get_xml*_local methods deprecated and will be removed. Use xmltodict package instead!'
-        self.logger.warning(deprecation_message)
-
-        import xml.etree.ElementTree as ET
+        self.logger.info(f'[{self.host}] Getting "{file_name}" as dictionary')
 
         try:
-            root = ET.parse(path).getroot()
-        except ET.ParseError as err:
-            self.logger.error(f'Failed to open file. {err}')
-            raise RuntimeError(err)
+            xml = self.get_content(file_name).stdout
+            xml_data = xmltodict.parse(xml, xml_attribs=xml_attribs)
 
-        if tag:
-            tag_text = root.find(tag).text
-            if tag_text.isdigit():
-                return int(tag_text)
-            return tag_text
-        return root
+        except TypeError as err:
+            self.logger.error(f'[{self.host}] File ({file_name}) not found.')
+            raise err
+        else:
+            return json.loads(json.dumps(xml_data))
+
+    def get_xml_local(self, file_name: str, xml_attribs: bool = False) -> dict:
+        """Parse specified xml file's content
+
+        :param file_name: XML file path
+        :return:
+        """
+
+        self.logger.info(f'[LOCAL] Getting "{file_name}" as dictionary')
+
+        try:
+            with open(file_name) as file:
+                xml = file.read()
+                xml_data = xmltodict.parse(xml, xml_attribs=xml_attribs)
+
+        except TypeError as err:
+            self.logger.error(f'[LOCAL] File ({file_name}) not found.')
+            raise err
+        else:
+            return json.loads(json.dumps(xml_data))
 
     def clean_directory(self, path: str, ignore_errors: bool = False):
         """Clean (remove) all files from a remote windows directory.
@@ -1532,3 +1512,14 @@ class WinOSClient:
         self.logger.info(f'Password: {self.password}')
         self.logger.info(f'Available: {self.is_host_available()}')
         self.logger.info(sys.version)
+
+
+def print_win_response(response):
+    """Pretty print PyWinOS response"""
+
+    print()
+    print('=' * 36)
+    print(f'Exit code: {response.exited}')
+    print(f'STDOUT: {response.stdout}')
+    print(f'STDERR: {response.stderr}')
+    print('=' * 36)
